#
#-----------------------------------------------------------------------------
## Header: General Commands ##

# delete all objects and reset pymol
reinitialize
# set the background color to white
bg_color white
# make the background transparent for ray trace 
set ray_opaque_background, 0
# set the ray trace mode
# normal color
set ray_trace_mode, 0
# normal color + black outline
#set ray_trace_mode,  1
# black outline only
#set ray_trace_mode,  2
# turn off shadows during ray trace
set ray_shadows, 0
# set the mouse mode for laptop.
config_mouse one_button
# run the python program for hydrogen bonding interactions.
# get ride of double bonds and skinny bonds to H
set stick_h_scale, 1
set valence, 0

run files/python/list_hbonds.py
#------put the python program list_hbonds.py
#------into the directory python.

## End of Header: General Commands ##
#
# 	Loren Williams, Georgia Tech
# 	pymol script for Helix G of Myoglobin 

#----------------------------------------
#
load files/helix_g_myo.pdb, helix_g_myo

create Helix_G_ROD, helix_g_myo
hide everything, Helix_G_ROD
show cartoon, Helix_G_ROD
set cartoon_cylindrical_helices,1, Helix_G_ROD
set cartoon_helix_radius, 1.3, Helix_G_ROD
remove (resi 101,119) and Helix_G_ROD
color lightorange, Helix_G_ROD
set cartoon_transparency, 0.3, Helix_G_ROD


create Helix_G_RIBBON, helix_g_myo
hide everything, Helix_G_RIBBON
show cartoon, Helix_G_RIBBON
set cartoon_fancy_helices, 0, Helix_G_RIBBON
color palegreen, Helix_G_RIBBON

create Helix_G_backbone, helix_g_myo and (name CA or name N or name C or name O or name CB or name H02) 
hide everything, Helix_G_backbone
show stick, Helix_G_backbone

create Helix_G_sidechains, helix_g_myo
hide everything, Helix_G_sidechains
show stick, Helix_G_sidechains
remove Helix_G_sidechain and (name H01,H03,H04,H05,H06,H07,H08,H09,H10,H11,H12,H13)

# color atoms by type
color wheat, name C* and (Helix_G_sidechains,Helix_G_backbone)
color red, name O* and (Helix_G_sidechains,Helix_G_backbone)
color blue, name N* and (Helix_G_sidechains,Helix_G_backbone)


dist G_hbond_NH_O, (name O and Helix_G_sidechains), (name H02 and Helix_G_sidechains), 2.4 

color black, G_hbond_NH_O
set label_size, -0.30, G_hbond_NH_O
set dash_width, 3.0, G_hbond_NH_O
set dash_gap, 0.3, G_hbond_NH_O
set label_position, (1.2,0,0), G_hbond_NH_O

#------------------------------13 atom ring------

create HB_ring, ( (resi 107 and (name C,O) or resi 108 and (name CA,N,C) or resi 109 and (name CA,N,C) or resi 110 and (name CA,N,C) or resi 111 and (name N,H02)) and helix_g_myo )

show stick, HB_ring
set_bond stick_radius, 0.3, HB_ring
color limon, HB_ring

label HB_ring and resi 107 and name C, "i"
label HB_ring and resi 108 and name CA, "i+1"
label HB_ring and resi 109 and name CA, "i+2"
label HB_ring and resi 110 and name CA, "i+3"
label HB_ring and resi 111 and name N, "i+4"

set label_color, black, HB_ring
set label_outline_color, black, HB_ring
set label_shadow_mode=2, HB_ring
set label_size, 20.0, HB_ring



#------------------------------phi/psi------torsion angles

dihedral phi_8,  resi 109 and name C and Helix_G_sidechains, resi 110 and name N and Helix_G_sidechains, resi 110 and name CA and Helix_G_sidechains, resi 110 and name C and Helix_G_sidechains

create phi_8_atoms,  ( ( (resi 109 and name C) or (resi 110 and name N) or (resi 110 and name CA) or (resi 110 and name C) ) and Helix_G_sidechains)

dihedral psi_8, resi 110 and name N and Helix_G_sidechains, resi 110 and name CA and Helix_G_sidechains, resi 110 and name C and Helix_G_sidechains, resi 111 and name N and Helix_G_sidechains

create psi_8_atoms,  ( ((resi 110 and name N) or (resi 110 and name CA) or (resi 110 and name C) or (resi 111 and name N) ) and Helix_G_sidechains)

show stick, phi_8_atoms
set stick_radius, 0.10, phi_8_atoms
label phi_8_atoms, name
show spheres, phi_8_atoms
alter phi_8_atoms, vdw=0.25
alter phi_8_atoms and name N, vdw=0.35
rebuild

show stick, psi_8_atoms
set stick_radius, 0.10, psi_8_atoms
label psi_8_atoms, name
show spheres, psi_8_atoms
alter psi_8_atoms, vdw=0.25
alter psi_8_atoms and name ca, vdw=0.35
rebuild

set label_color, red, phi_8
set label_color, red, phi_8_atoms
color red, phi_8

set label_color, blue, psi_8
set label_color, blue, psi_8_atoms
color blue, psi_8

set dihedral_size, 1.9, phi_8
set dihedral_size, 1.9, psi_8
set line_width, 6, phi_8
set line_width, 6, psi_8


#--PLANES-------------------------------
python
import sys
sys.path.append('./files/')
from draw_plane_cgo import *

for i in range (101, 119):
	plnme = "plane" + str(i-99)
	st1= 'resi ' + str(i) + ' and name CA'
	st2= 'resi ' + str(i) + ' and name O'
	st3= 'resi ' + str(i+1) + ' and name H02'
	st4= 'resi ' + str(i+1) + ' and name CA'
	cmd.select("st1", st1)
	cmd.select("st2", st2)
	cmd.select("st3", st3)
	cmd.select("st4", st4)
	cstr = ''
	ccode = i%3
	if ccode == 1:
		cstr = "(255,0,255)"
	elif ccode == 2:
		cstr = "(255,255,0)"
	else:
		cstr = "(0,255,255)"

	draw_plane(plnme, "st1", "st2", "st3", "st4",cstr)
python end

delete st1
delete st2
delete st3
delete st4

#-------------------------------
disable all
enable Helix_G_backbone
enable Helix_G_ribbon
enable Helix_G
enable G_hbond_NH_O
enable plane*
delete helix_g_myo

set_view (\
    -0.925666153,   -0.361897737,   -0.110276967,\
     0.353169799,   -0.931106627,    0.091087408,\
    -0.135642365,    0.045374848,    0.989712894,\
     0.000000000,    0.000000000,  -58.371692657,\
    27.696598053,   14.564017296,    8.807390213,\
    40.290187836,   76.453193665,  -20.000000000 )
### cut above here and paste into script ### 

